% SWZ Poster-Vorlage
% (erstellt von Alexander Herzog, alexander.herzog@tu-clausthal.de)



% Dieses Paket basiert auf der scrartcl-Klasse.

% Die Farben "SWZ Orange" und "SWZ Grau" werden über folgende Farbnamen zur
% Verfügung gestellt: SWZOrange, SWZGray, SWZGrey.
% Die Farben können per \color{name} bzw. \textcolor{name} verwendet werden.

% Der Titel wird über \SWZPrintTitle ausgegeben. Vorher müssen eine erste
% Überschriftzeile per \def\SWZTitleA{...} und ein Autorenname per
% \def\SWZAuthor{...} definiert werden. Optional kann eine zweite
% Überschrifzeile per \def\SWZTitleB{...} angegeben werden.

% Ein-, zwei- oder dreispaltige Textboxen werden per
% \makeSWZBoxA{\NameDerBox}{...}, \makeSWZBoxB{\NameDerBox}{...} oder
% \makeSWZBoxC{\NameDerBox}{...} erstellt (aber noch nicht ausgegeben).

% Ein-, zwei- oder dreispaltige Bilder können per \printSWZPictureA{...},
% \printSWZPictureB{...} oder \printSWZPictureC{...} ausgegeben werden.

% Die Ausgabe der Boxen erfolgt am Ende wie folgt:
% \begin{picture}(0,0)
% \unitlength4.5\LogoHoehe
% \put(0,0){\usebox{\BoxSpalteEins}}
% \put(1,0){\usebox{\BoxSpalteZwei}}
% \put(2,0){\usebox{\BoxSpalteDrei}}
% \end{picture}





% Initialisierung
\def\filedate{2014/26/06}
\def\fileversion{1.0.0}
\def\filename{SWZPosterEn.cls}
\NeedsTeXFormat{LaTeX2e}[2001/06/01]

\ProvidesClass{SWZPosterEn}[\filedate\space v\fileversion\space SWZPosterEn class]

\usepackage{anyfontsize}
\usepackage{lmodern}

\IfFileExists{graphicx.sty}
  {\RequirePackage{graphicx}}
  {\ClassError{SWZPoster}{Missing file graphicx.sty!}{Get current LaTeX2e!}}

\IfFileExists{color.sty}
  {\RequirePackage{color}}
  {\ClassError{SWZPoster}{Missing file color.sty!}{Get current LaTeX2e!}}

\IfFileExists{geometry.sty}
  {\RequirePackage{geometry}}
  {\ClassError{SWZPoster}{Missing file geometry.sty!}{Get current LaTeX2e!}}

\IfFileExists{fancyhdr.sty}
  {\RequirePackage{fancyhdr}}
  {\ClassError{SWZPoster}{Missing file fancyhdr.sty!}{Get current LaTeX2e!}}

\PassOptionsToClass{fontsize=34pt}{scrartcl}
\PassOptionsToClass{DIV=6}{scrartcl}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}
\ProcessOptions\LoadClass{scrartcl}





% Definition der SWZ-Farben
\definecolor{SWZOrange}{RGB}{255,127,0}
\definecolor{SWZGray}{RGB}{51,51,43}
\definecolor{SWZGrey}{RGB}{51,51,43}
\definecolor{SWZDarkGray}{rgb}{0.2,0.2,0.2}
\definecolor{SWZDarkGrey}{rgb}{0.2,0.2,0.2}





% Titelbox vorbereiten
\newcommand{\SWZTitleFont}{\sffamily\bfseries\fontsize{100}{108}\selectfont}
\newcommand{\SWZAuthorFont}{\sffamily\itshape\fontsize{60}{64}\selectfont}

\def\SWZPrintTitle{
\newsavebox{\SWZHeading}
\sbox{\SWZHeading}{
  \unitlength\LogoHoehe
  \begin{picture}(0,0)
	  \put(0,2.1){\SWZTitleFont\SWZTitleA}
	  \ifdefined\SWZTitleB
	    \put(0,1.3){\SWZTitleFont\SWZTitleB}
	    \put(0,0.7){\SWZAuthorFont\textcolor{SWZDarkGrey}{\SWZAuthor}}
	  \else
	    \put(0,1.55){\SWZAuthorFont\textcolor{SWZDarkGrey}{\SWZAuthor}}
	  \fi
  \end{picture}
}
\usebox{\SWZHeading}
}





% SWZ-Logo und SWZ-Bogen ausgeben
\def\includeSWZLogo{\includegraphics[height=\LogoHoehe]{SWZLogo_en}}
\def\includeSWZBogen{\includegraphics[height=\paperheight]{SWZBogen}}
\def\includeTUCLogo{\includegraphics[height=0.5\LogoHoehe]{TUCLogo_en}}
\def\includeUGoLogo{\includegraphics[height=0.5\LogoHoehe]{UGoLogo}}

\newlength{\LogoHoehe}
\setlength{\LogoHoehe}{0.0588\paperwidth}

\geometry{left=3.5\LogoHoehe,right=0.5\LogoHoehe,top=4.5\LogoHoehe,bottom=0.5\LogoHoehe,ignorehead,ignorefoot,headsep=-1ex}

\newsavebox{\@SWZFrame}
\sbox{\@SWZFrame}{
  \unitlength\LogoHoehe
  \begin{picture}(0,0)
	  \put(9,3){\includeSWZLogo}
	  \put(-3.5,-20.034){\includeSWZBogen}
	  \put(0,-18.35){\sffamily The SWZ is a common interdisciplinary research facility in simulation science of}
	  \put(0,-19){\includeTUCLogo}
	  \put(3,-19){\includeUGoLogo}
  \end{picture}
}

\fancypagestyle{SWZPoster}{
  \fancyhead{}\fancyfoot{}
  \fancyfoot[L]{}
  \fancyhead[L,LO]{\usebox{\@SWZFrame}}
  \def\headrulewidth{0pt}\def\footrulewidth{0pt}
}
\thispagestyle{SWZPoster}





% Textboxen vorbereiten
\newcommand{\makeSWZBoxA}[2]{
  \newsavebox{#1}\begin{lrbox}{#1}
  \begin{minipage}[t]{4\LogoHoehe}
  \sffamily
  #2
  \end{minipage}
  \end{lrbox}
}

\newcommand{\makeSWZBoxB}[2]{
  \newsavebox{#1}\begin{lrbox}{#1}
  \begin{minipage}[t]{8.5\LogoHoehe}
  \sffamily
  #2
  \end{minipage}
  \end{lrbox}
}

\newcommand{\makeSWZBoxC}[2]{
  \newsavebox{#1}\begin{lrbox}{#1}
  \begin{minipage}[t]{13\LogoHoehe}
  \sffamily
  #2
  \end{minipage}
  \end{lrbox}
}





% Bilder in passender Breite ausgeben
\newcommand{\printSWZPictureA}[1]{\null\centerline{\includegraphics[width=4\LogoHoehe]{#1}}}
\newcommand{\printSWZPictureB}[1]{\null\centerline{\includegraphics[width=8.5\LogoHoehe]{#1}}}
\newcommand{\printSWZPictureC}[1]{\null\centerline{\includegraphics[width=13\LogoHoehe]{#1}}}





% Weitere Corporate Design Vorgaben
\parindent0pt
\setkomafont{section}{\Large\bfseries\sffamily\color{SWZOrange}\raggedright{}}
\setkomafont{subsection}{\large\bfseries\sffamily\color{SWZOrange}\raggedright{}}

\endinput